@@ -5,7 +5,7 @@ examples.hide_show_prompt_toolkit
 Usage of the ``hide`` and ``show`` methods with prompt_toolkit's printing.
 Starting from yaspin v1.1.0 handled by ``hidden`` context manager.
 
-Requires python-prompt-tooklit >= 2.0.1
+Requires python-prompt-toolkit >= 2.0.1
 https://github.com/jonathanslenders/python-prompt-toolkit/
 
 .. code:: bash
@@ -17,13 +17,12 @@ import time
 
 from yaspin import yaspin
 
-
 try:
     from prompt_toolkit import HTML, print_formatted_text
     from prompt_toolkit.styles import Style
 except ImportError:
     print(
-        "This example requires python-prompt-tooklit >= 2.0.1:\n"
+        "This example requires python-prompt-toolkit >= 2.0.1:\n"
         "https://github.com/jonathanslenders/python-prompt-toolkit/\n"
         "\nTo install it, run:\n"
         'pip install "prompt_toolkit>=2.0.1"'
@@ -39,7 +38,6 @@ style = Style.from_dict({"msg": "#4caf50 bold", "sub-msg": "#616161 italic"})
 
 
 with yaspin(text="Downloading images") as sp:
-
     # task 1
     time.sleep(1)
     with sp.hidden():
