@@ -8,11 +8,11 @@ Tests data.
 import signal
 import sys
 
+from termcolor import ATTRIBUTES, COLORS, HIGHLIGHTS
+
 import pytest
 
-from yaspin.constants import COLOR_MAP
-from yaspin.signal_handlers import default_handler, fancy_handler
-
+from yaspin.core import default_handler, fancy_handler
 
 frame_cases = [
     # XXX: try byte strings
@@ -111,10 +111,7 @@ def color_id_func(case):
     else:
         color = case
 
-    if not color or callable(color):
-        val = repr(color)
-    else:
-        val = color
+    val = repr(color) if not color or callable(color) else color
 
     return val
 
@@ -143,6 +140,16 @@ def attrs_id_func(case):
         ("magenta", "magenta"),
         ("cyan", "cyan"),
         ("white", "white"),
+        # New highlights (from termcolor v2.2.0)
+        ("black", "black"),
+        ("dark_grey", "dark_grey"),
+        ("light_grey", "light_grey"),
+        ("light_red", "light_red"),
+        ("light_green", "light_green"),
+        ("light_yellow", "light_yellow"),
+        ("light_blue", "light_blue"),
+        ("light_magenta", "light_magenta"),
+        ("light_cyan", "light_cyan"),
         # Unsupported text colors
         ("Red", ValueError()),
         ("orange", ValueError()),
@@ -167,6 +174,16 @@ def color_test_cases(request):
         ("on_magenta", "on_magenta"),
         ("on_cyan", "on_cyan"),
         ("on_white", "on_white"),
+        # New highlights (from termcolor v2.2.0)
+        ("on_black", "on_black"),
+        ("on_dark_grey", "on_dark_grey"),
+        ("on_light_grey", "on_light_grey"),
+        ("on_light_red", "on_light_red"),
+        ("on_light_green", "on_light_green"),
+        ("on_light_yellow", "on_light_yellow"),
+        ("on_light_blue", "on_light_blue"),
+        ("on_light_magenta", "on_light_magenta"),
+        ("on_light_cyan", "on_light_cyan"),
         # Unsupported highlights
         ("on_foo", ValueError()),
     ],
@@ -201,7 +218,7 @@ def attrs_test_cases(request):
 @pytest.fixture(
     scope="session",
     ids=color_id_func,
-    params=sorted([k for k, v in COLOR_MAP.items() if v == "color"]),
+    params=sorted(COLORS.keys()),
 )
 def supported_colors(request):
     return request.param
@@ -210,7 +227,7 @@ def supported_colors(request):
 @pytest.fixture(
     scope="session",
     ids=color_id_func,
-    params=sorted([k for k, v in COLOR_MAP.items() if v == "on_color"]),
+    params=sorted(HIGHLIGHTS.keys()),
 )
 def supported_highlights(request):
     return request.param
@@ -220,8 +237,8 @@ def supported_highlights(request):
     scope="session",
     ids=attrs_id_func,
     params=sorted(
-        [[k] for k, v in COLOR_MAP.items() if v == "attrs"]
-        + [  # noqa: W503
+        [[a] for a in ATTRIBUTES]
+        + [
             ["bold", "dark"],
             ["blink", "concealed", "reverse"],
             ["underline", "concealed", "bold", "dark", "blink", "reverse"],
