@@ -21,7 +21,7 @@ def test_input_converted_to_unicode(text, frames, interval, reversal, side):
 
     assert not isinstance(sp._frames, bytes)
 
-    if isinstance(sp._frames, (list, tuple)):
+    if isinstance(sp._frames, list | tuple):
         assert isinstance(sp._frames[0], str)
 
     assert isinstance(sp._text, str)
@@ -44,9 +44,10 @@ def test_repr(text, frames, interval):
     assert isinstance(repr(sp), str)
 
 
-def test_compose_out_with_color(
-    color_test_cases, on_color_test_cases, attrs_test_cases
-):
+def test_compose_out_with_color(monkeypatch, color_test_cases, on_color_test_cases, attrs_test_cases):
+    # Starting from v2.3.0, termcolor respects $NO_COLOR env var
+    # https://github.com/termcolor/termcolor/pull/38
+    monkeypatch.setenv("FORCE_COLOR", "1")
     color, color_exp = color_test_cases
     on_color, on_color_exp = on_color_test_cases
     attrs, attrs_exp = attrs_test_cases
@@ -91,12 +92,9 @@ def test_write(monkeypatch, capsys, text, isatty_fixture):
 
     out, _ = capsys.readouterr()
     # cleans stdout from _clear_line
-    if isatty_fixture:
-        out = out.replace("\r\033[K", "")
-    else:
-        out = out.replace("\r", "")
+    out = out.replace("\r\x1b[K", "") if isatty_fixture else out.replace("\r", "")
 
-    assert isinstance(out, (str, bytes))
+    assert isinstance(out, str | bytes)
     assert out[-1] == "\n"
     if text:
         assert out[:-1] == text
@@ -122,6 +120,7 @@ def test_hide_show(monkeypatch, capsys, text, request, isatty_fixture):
 
     # Ensure that sp.stop() will be executed
     def teardown():
+        # Stop the spinner in teardown to ensure cleanup
         sp.stop()
 
     request.addfinalizer(teardown)
@@ -147,12 +146,9 @@ def test_hide_show(monkeypatch, capsys, text, request, isatty_fixture):
     out, _ = capsys.readouterr()
 
     # cleans stdout from _clear_line
-    if isatty_fixture:
-        out = out.replace("\r\033[K", "")
-    else:
-        out = out.replace("\r", "")
+    out = out.replace("\r\x1b[K", "") if isatty_fixture else out.replace("\r", "")
 
-    assert isinstance(out, (str, bytes))
+    assert isinstance(out, str | bytes)
     assert out[-1] == "\n"
     if text:
         assert out[:-1] == text
@@ -210,16 +206,11 @@ def test_spinner_hiding_with_context_manager(monkeypatch, capsys, isatty_fixture
 
     # make sure no spinner text was printed while the spinner was hidden
     out, _ = capsys.readouterr()
-    if isatty_fixture:
-        out = out.replace("\r\033[K", "")
-    else:
-        out = out.replace("\r", "")
+    out = out.replace("\r\x1b[K", "") if isatty_fixture else out.replace("\r", "")
     assert f"{HIDDEN_START}\n{HIDDEN_END}" in out
 
 
-def test_spinner_nested_hiding_with_context_manager(
-    monkeypatch, capsys, isatty_fixture
-):
+def test_spinner_nested_hiding_with_context_manager(monkeypatch, capsys, isatty_fixture):
     HIDDEN_START = "hidden start"
     HIDDEN_END = "hidden end"
     monkeypatch.setattr(sys.stdout, "isatty", lambda: isatty_fixture)
@@ -244,10 +235,7 @@ def test_spinner_nested_hiding_with_context_manager(
 
     # make sure no spinner text was printed while the spinner was hidden
     out, _ = capsys.readouterr()
-    if isatty_fixture:
-        out = out.replace("\r\033[K", "")
-    else:
-        out = out.replace("\r", "")
+    out = out.replace("\r\x1b[K", "") if isatty_fixture else out.replace("\r", "")
     assert f"{HIDDEN_START}\n{HIDDEN_END}" in out
 
 
@@ -261,7 +249,7 @@ def test_spinner_hiding_with_context_manager_and_exception():
     except ValueError:
         pass
     else:
-        assert False, "Expected a ValueError, something has eaten the exception"
+        raise AssertionError("Expected a ValueError, something has eaten the exception")
 
     # make sure spinner is unhidden again
     assert sp._hidden_level == 0
@@ -274,7 +262,7 @@ def test_spinner_hiding_with_context_manager_and_exception():
     "obj, obj_str",
     [
         ("foo", "foo"),
-        (dict(cat="meow"), "{'cat': 'meow'}"),
+        ({"cat": "meow"}, "{'cat': 'meow'}"),
         (23, "23"),
         (["foo", "bar", "'", 23], """['foo', 'bar', "'", 23]"""),
     ],
