@@ -47,9 +47,7 @@ def test_timer_in_progress():
     assert re.search(r"\(\d+:\d{2}:\d{2}.\d{2}\)", sp._last_frame) is not None
 
 
-@pytest.mark.parametrize(
-    "interval, expected", [(0.994, "(0:00:00.99)"), (0.996, "(0:00:01.00)")]
-)
+@pytest.mark.parametrize("interval, expected", [(0.994, "(0:00:00.99)"), (0.996, "(0:00:01.00)")])
 def test_timer_rounding(interval, expected):
     sp = yaspin(timer=True)
     sp.start()
