@@ -10,7 +10,7 @@ from collections import namedtuple
 import pytest
 
 from yaspin import Spinner, yaspin
-from yaspin.base_spinner import default_spinner
+from yaspin.core import default_spinner
 
 
 @pytest.mark.parametrize(
@@ -44,3 +44,10 @@ from yaspin.base_spinner import default_spinner
 def test_set_spinner(spinner, expected):
     sp = yaspin(spinner)
     assert sp.spinner == expected
+
+
+def test_decorator_usage():
+    @yaspin()
+    def decorated_func(): ...
+
+    decorated_func()
